import datetime
from haystack import indexes
from models import Article

class ArticleIndex(indexes.SearchIndex, indexes.Indexable):
    text        = indexes.CharField(document=True, use_template=True)
    author      = indexes.CharField(model_attr='user')
    created     = indexes.DateTimeField(model_attr='created')

    def get_model(self):
        return Topic

    def index_queryset(self, using=None):
        return self.get_model().objects.filter(created__lte=datetime.datetime.now())



from django.contrib.auth.models import User
from django.conf.urls.defaults import url

from tastypie.authorization import Authorization, DjangoAuthorization
from tastypie.resources import ModelResource, ALL, ALL_WITH_RELATIONS
from tastypie import fields

from models import *

class NewsResource(ModelResource):
    class Meta:
        queryset        = Article.objects.filter()
        resource_name   = 'news'
        detail_uri_name = 'slug'

    def determine_format(self, request):
        return "application/json"

    def prepend_urls(self):
        return [
            url(r"^(?P<resource_name>%s)/(?P<slug>[\w\d_.-]+)/$" % 
                self._meta.resource_name, self.wrap_view('dispatch_detail'), name="api_dispatch_detail"),
        ]



import MySQLdb

from django.core.management.base import BaseCommand, CommandError
from django.conf import settings

class Command(BaseCommand):
    help = "Fixes 'Incorrect String Value' errors when trying to save unicode characters."

    def handle(self, *args, **options):
        hostname    = settings.DATABASES["default"]["HOST"]
        port        = settings.DATABASES["default"]["PORT"]
        user        = settings.DATABASES["default"]["USER"]
        password    = settings.DATABASES["default"]["PASSWORD"]
        dbname      = settings.DATABASES["default"]["NAME"]

        if hostname == "":
            hostname = "localhost"

        db = MySQLdb.connect(host=hostname, user=user, passwd=password, db=dbname)
        cursor = db.cursor()

        cursor.execute("ALTER DATABASE `%s` CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci'" % dbname)

        sql = "SELECT DISTINCT(table_name) FROM information_schema.columns WHERE table_schema = '%s'" % dbname
        cursor.execute(sql)

        results = cursor.fetchall()
        for row in results:
            sql = "ALTER TABLE `%s` convert to character set DEFAULT COLLATE DEFAULT" % (row[0])
            cursor.execute(sql)

        db.close()
        self.stdout.write("Finised converting database.")
